Jump to content

[fix]Primal Tenacity


Guest laise

Recommended Posts

What bug does the patch fix? What features does the patch add?

fixes Primal Tenacity talent according to 3.1 patch notes:

Patch 3.1.0 (2009-04-14): The damage reduction while stunned effect now only works in Cat Form

For which repository revision was the patch created?

9573

Is there a thread in the bug report section or at lighthouse? If yes, please add a link to the thread.

haven't seen any

Who has been writing this patch? Please include either forum user names or email addresses.

me

diff --git a/src/game/Unit.cpp b/src/game/Unit.cpp
index 1ae628e..57729a4 100644
--- a/src/game/Unit.cpp
+++ b/src/game/Unit.cpp
@@ -2000,8 +2000,8 @@ void Unit::CalcAbsorbResist(Unit *pVictim,SpellSchoolMask schoolMask, DamageEffe
                // Primal Tenacity
                if (spellProto->SpellIconID == 2253)
                {
-                    //reduces all damage taken while Stunned
-                    if (unitflag & UNIT_FLAG_STUNNED)
+                    //reduces all damage taken while Stunned & in Cat Form
+                    if (pVictim->m_form == FORM_CAT && (unitflag & UNIT_FLAG_STUNNED))
                        RemainingDamage -= RemainingDamage * currentAbsorb / 100;
                    continue;
                }

Link to comment
Share on other sites

×
×
  • Create New...

Important Information

We have placed cookies on your device to help make this website better. You can adjust your cookie settings, otherwise we'll assume you're okay to continue. Privacy Policy Terms of Use